from django.test import TestCase
from django.contrib.admin import ModelAdmin

from ..admin import UserModelAdmin
from ..models import UserModel


class UserModelAdminTest(TestCase):
    def setUp(self):
        self.obj = UserModelAdmin(UserModel, UserModelAdmin)

    def test_instance(self):
        self.assertIsInstance(self.obj, ModelAdmin)



from django.urls import path

from .views import accounts_login, accounts_authorize, user_detail, user_logout


app_name = 'accounts'

urlpatterns = [
    path('login', accounts_login, name='login'),
    path('authorize', accounts_authorize, name='authorize'),
    path('user', user_detail, name='user_detail'),
    path('logout', user_logout, name='logout')
]



from django.views.generic import RedirectView, View
from django.contrib.auth import login, authenticate, logout
from django.shortcuts import redirect, render, resolve_url as r
from django.contrib.auth.decorators import login_required
from django.conf import settings

from .oauth import OAuthUsp
from .transform import Transform
from .models import UserModel

REDIRECT_AFTER_LOGOUT_URL = getattr(settings, 'REDIRECT_AFTER_LOGOUT_URL')


class OAuthLogin(RedirectView):
    def get(self, request, *args, **kwargs):
        self.detail_if_logedin(request)
        self.set_next_url(request)
        return super().get(request, *args, **kwargs)

    def get_redirect_url(self, *args, **kwargs):
        return self.redirect_uri.url

    def setup(self, request, *args, **kwargs):
        oauth_usp = OAuthUsp()
        self.redirect_uri = oauth_usp.get_authorize_redirect(request)
        return super().setup(request, *args, **kwargs)

    def detail_if_logedin(self, request):
        if request.user.is_authenticated:
            self.redirect_uri = redirect(r('accounts:user_detail'))

    def set_next_url(self, request):
        request.session['next'] = '/'
        if 'next' in request.GET:
            request.session['next'] = request.GET['next']


accounts_login = OAuthLogin.as_view()


class OAuthAuthorize(View):
    def setup(self, request, *args, **kwargs):
        self.oauth_usp = OAuthUsp()
        return super().setup(request, *args, **kwargs)

    def get(self, request, *args, **kwargs):
        self.profile = self.oauth_usp.get_resource(request)
        self.data_transform()
        self.persist_user()
        self.authenticate_user(request)
        redirect_path = self.get_redirect_path(request)
        return redirect(redirect_path)

    def data_transform(self):
        transform = Transform()
        self.profile = transform.transform_data(self.profile)

    def persist_user(self):
        self.user, create = UserModel.objects.update_or_create_user(
            **self.profile)

    def authenticate_user(self, request):
        user = authenticate(request, username=self.user.login,
                            password=self.user.wsuserid)
        if user:
            login(request=request, user=user)

    def get_redirect_path(self, request):
        next_path = request.session.get('next')
        if next_path:
            return request.session.pop('next')
        return r('accounts:user_detail')


accounts_authorize = OAuthAuthorize.as_view()


@login_required
def user_detail(request):
    context = {'user': request.user}
    return render(request, 'user.html', context=context)


def user_logout(request):
    logout(request)
    return redirect(REDIRECT_AFTER_LOGOUT_URL)



from faker import Faker
from faker.providers import BaseProvider, internet


fake = Faker('pt_BR')

data = {
    'login': fake.user_name(),
    'name': fake.name(),
    'user_type': fake.random_elements(elements=('I', 'E'))[0],
    'main_email': fake.email(),
    'alternative_email': fake.email(),
    'usp_email': fake.email(),
    'formatted_phone': fake.phone_number(),
    'wsuserid': fake.msisdn(),
    'bind': '[]',
}


class Resource(BaseProvider):
    def resource(self):
        return {
            'loginUsuario': data.get('login'),
            'nomeUsuario': data.get('name'),
            'tipoUsuario': data.get('user_type'),
            'emailPrincipalUsuario': data.get('main_email'),
            'emailAlternativoUsuario': data.get('alternative_email'),
            'emailUspUsuario': data.get('usp_email'),
            'numeroTelefoneFormatado': data.get('formatted_phone'),
            'wsuserid': data.get('wsuserid'),
            'vinculo': data.get('bind')
        }

    def resource_transformed(self):
        return data


fake.add_provider(Resource)



from django.http import HttpResponseForbidden


class OAuthUspMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        if request.user.is_authenticated:
            return self.alllowed_unidade_or_forbidden(request)

        response = self.get_response(request)

        return response

    def alllowed_unidade_or_forbidden(self, request):
        if not request.user.unidade_is_allowed():
            return HttpResponseForbidden()

        return self.get_response(request)



import json
from django.db import models
from django.contrib.auth.models import AbstractBaseUser, PermissionsMixin
from django.utils.translation import gettext_lazy as _
from django.core.mail import send_mail
from django.conf import settings

from .managers import UserManager


class UserModel(AbstractBaseUser, PermissionsMixin):
    login = models.CharField(_("login"), max_length=50, unique=True)
    name = models.CharField(_("name"), max_length=100)
    user_type = models.CharField(_("user type"), max_length=1)
    main_email = models.EmailField(_("main email"), max_length=50)
    alternative_email = models.EmailField(_("alternative email"),
                                          max_length=254)
    usp_email = models.EmailField(_("email usp"), max_length=254)
    formatted_phone = models.CharField(_("phone"), max_length=50)
    wsuserid = models.CharField(_("wsuserid"), max_length=1024)
    bind = models.TextField(_("bind"))
    is_staff = models.BooleanField(_("is staff"))
    is_active = models.BooleanField(_("is active"))
    date_joined = models.DateTimeField(_("Joined at"), auto_now_add=True)

    USERNAME_FIELD = 'login'
    REQUIRED_FIELDS = ['name', 'user_type', 'main_email']
    EMAIL_FIELD = 'main_email'
    ALLOWED_UNIDADES = str(settings.ALLOWED_UNIDADES)

    class Meta:
        verbose_name = _('user')
        verbose_name_plural = _('users')

    objects = UserManager()

    def get_full_name(self):
        return self.name

    def get_short_name(self):
        names = self.name.split()
        return names[0]

    def email_user(self, subject, message, from_email=None):
        send_mail(subject, message, from_email, [self.main_email])

    def get_phone(self):
        return self.formatted_phone

    def is_servidor(self):
        bind = self.get_bind()
        for item in bind:
            if item["tipoVinculo"] == 'SERVIDOR':
                return True

        return False

    def unidade_is_allowed(self):
        bind = self.get_bind()
        for item in bind:
            codigo_unidade = item["codigoUnidade"]
            if str(codigo_unidade) in self.ALLOWED_UNIDADES:
                return True

        return False

    def get_bind(self):
        bind = self.bind.replace("'", '"')
        return json.loads(bind)



from django.test import TestCase

from ..transform import Transform, Mapper
from .faker import fake


class TransformTest(TestCase):
    def setUp(self):
        self.obj = Transform()

    def test_has_mapper_attribute(self):
        self.assertTrue(hasattr(self.obj, 'mapper'))

    def test_mapper(self):
        expected = fake.resource_transformed()
        resp = self.obj.transform_data(fake.resource())
        self.assertDictEqual(expected, resp)


class MapperTest(TestCase):
    def setUp(self):
        self.obj = Mapper()

    def test_is_instance_of_object(self):
        self.assertIsInstance(self.obj, object)

    def test_get_mapper(self):
        resp = self.obj.get_mapper()
        expected = self.mock_mapper()
        self.assertDictEqual(resp, expected)

    def mock_mapper(self):
        return {
            'loginUsuario': 'login',
            'nomeUsuario': 'name',
            'tipoUsuario': 'user_type',
            'emailPrincipalUsuario': 'main_email',
            'emailAlternativoUsuario': 'alternative_email',
            'emailUspUsuario': 'usp_email',
            'numeroTelefoneFormatado': 'formatted_phone',
            'wsuserid': 'wsuserid',
            'vinculo': 'bind'
        }



from django.test import TestCase
from django.shortcuts import resolve_url as r
from django.http import HttpRequest, QueryDict
from django.contrib.sessions.backends.db import SessionStore
from django.contrib.auth.models import AnonymousUser
from django.test import Client

from ..views import OAuthAuthorize, OAuthLogin
from ..models import UserModel
from .mock import mock_oauth
from .faker import data as user_data


class LoginViewsTest(TestCase):
    @mock_oauth
    def setUp(self):
        self.resp = self.client.get(r('accounts:login'))

    def test_status_code(self):
        """Status code should be 302"""
        self.assertEqual(302, self.resp.status_code)


class LoginViewsUserLogedInTest(TestCase):
    @mock_oauth
    def setUp(self):
        user_data['bind'] = '[{"codigoUnidade": "14"}]'
        self.user = UserModel.objects.create_user(**user_data)
        self.client.force_login(self.user)
        self.resp = self.client.get(r('accounts:login'))

    def test_redirect_to_user_detail(self):
        """Loged in user should be redirect to user detail"""
        expected = '/user'
        self.assertEqual(self.resp.url, expected)


class AuthorizeViewTest(TestCase):
    @mock_oauth
    def setUp(self):
        self.request = HttpRequest()
        query = QueryDict(
            'oauth_token=12345oauth&oauth_verifier=12345veriifer')

        self.request.GET = query

        session = SessionStore()
        setattr(self.request, 'session', session)

        request_token = dict(
            oauth_token='token123', oauth_token_secret='oauth_token_secret123',
            oauth_verifier='verifier123')
        data = {"data": {"request_token": request_token}}
        self.request.session['_state_usp_12345oauth'] = data

        user = UserModel.objects.create_user(**user_data)
        setattr(user, 'wsuserid', 'oiuasd098')
        setattr(self.request, 'user', user)

        self.obj = OAuthAuthorize()

    @ mock_oauth
    def test_user_has_been_presisted(self):
        self.obj.setup(self.request)
        self.obj.get(self.request)
        self.assertTrue(UserModel.objects.exists())

    @ mock_oauth
    def test_user_loged_in(self):
        self.obj.setup(self.request)
        self.obj.get(self.request)
        self.assertTrue(self.request.user.is_authenticated)

    @ mock_oauth
    def test_response_status_code(self):
        self.obj.setup(self.request)
        resp = self.obj.get(self.request)
        self.assertTrue(302, resp.status_code)


class OAuthLoginTest(TestCase):
    def setUp(self):
        self.obj = OAuthLogin()

    @mock_oauth
    def test_next_url(self):
        request = HttpRequest()
        session = SessionStore()

        setattr(request, 'session', session)
        setattr(request, 'user', AnonymousUser())

        self.obj.setup(request)
        self.obj.get(request)

        expected = '/'
        self.assertEqual(self.obj.request.session.get('next'), expected)


class UserDetailViewLogeInTest(TestCase):
    def setUp(self):
        self.user = UserModel.objects.create_user(**user_data)
        self.client.force_login(self.user)
        self.resp = self.client.get(r('accounts:user_detail'))

    def test_status_code(self):
        self.assertEqual(200, self.resp.status_code)

    def test_authentication_required(self):
        client = Client()
        resp = client.get(r('accounts:user_detail'))
        self.assertEqual(302, resp.status_code)

    def test_template(self):
        self.assertTemplateUsed(self.resp, 'main.html')
        self.assertTemplateUsed(self.resp, 'user.html')

    def test_context_has_user(self):
        context = self.resp.context
        self.assertEqual(self.user, context.get('user'))

    def test_template_has_user_data(self):
        user_data_keys = user_data.keys()

        for info in user_data_keys:
            user_info = user_data.get(info)
            excluded = ['bind', 'login', 'wsuserid', 'is_staff',
                        'is_active', 'date_joined']
            if info not in excluded:
                with self.subTest():
                    self.assertContains(self.resp, user_info)


class OAuthLogoutTest(TestCase):
    def setUp(self):
        user = UserModel.objects.create_user(**user_data)
        self.client.force_login(user)
        self.resp = self.client.get(r('accounts:logout'))

    def test_status_code(self):
        self.assertEqual(302, self.resp.status_code)

    def test_user_logged_out(self):
        self.assertFalse(self.resp.wsgi_request.user.is_authenticated)



from django.test import TestCase
from django.contrib.auth.models import BaseUserManager

from ..managers import UserManager


class UserManagerTest(TestCase):
    def setUp(self):
        self.obj = UserManager()

    def test_is_instance_of_base_user_manager(self):
        self.assertIsInstance(self.obj, BaseUserManager)



import os
from pathlib import Path
from dj_database_url import parse as dburl

BASE_DIR = Path(__file__).resolve(strict=True).parent.parent


SECRET_KEY = 'alterar:my-secret-key'

AUTH_USER_MODEL = 'accounts.UserModel'

OAUTH_CALLBACK_ID = '4'

AUTHLIB_OAUTH_CLIENTS = {
    'usp': {
        'client_id': 'my_client_id',
        'client_secret': 'my_secret'
    }
}


INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_extensions',
    'django_oauth_usp.accounts'
]

ALLOWED_UNIDADES = [14]
REDIRECT_URI = '/user'
REDIRECT_AFTER_LOGOUT_URL = '/login'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django_oauth_usp.accounts.middleware.OAuthUspMiddleware',
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': './db.sqlite3'
    }
}

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

ROOT_URLCONF = 'django_oauth_usp.urls'

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'


from django.test import TestCase
from django.core import mail
from django.contrib.auth.models import AbstractBaseUser

from ..models import UserModel


class UserModelTest(TestCase):
    def setUp(self):
        self.obj = UserModel()

    def test_is_instance_of_model(self):
        self.assertIsInstance(self.obj, AbstractBaseUser)

    def test_has_parametters(self):
        parametters = ('login', 'name', 'user_type', 'main_email',
                       'alternative_email', 'usp_email',
                       'formatted_phone', 'wsuserid', 'bind', 'is_staff',
                       'is_active', 'date_joined', 'last_login')
        for expected in parametters:
            with self.subTest():
                message = '{} not found.'.format(expected)
                self.assertTrue(hasattr(self.obj, expected), msg=message)

    def test_has_get_full_name_attribute(self):
        self.assertTrue(hasattr(self.obj, 'get_full_name'))

    def test_has_attribute_get_short_name(self):
        self.assertTrue(hasattr(self.obj, 'get_short_name'))

    def test_create_user(self):
        """User must exists on database"""
        self.make_user()
        self.assertTrue(UserModel.objects.exists())

    def test_get_full_name(self):
        user = self.make_user()
        self.assertEqual('Marc Stold Further', user.get_full_name())

    def test_get_short_name(self):
        user = self.make_user()
        self.assertEqual('Marc', user.get_short_name())

    def test_email_user(self):
        user = self.make_user()
        user.email_user(subject='email test', message='message test',
                        from_email='acesso@test.com')
        self.assertTrue(mail.outbox[0])

    def test_get_phone(self):
        user = self.make_user(formatted_phone='3334455')
        self.assertEqual('3334455', user.get_phone())

    def test_is_servidor(self):
        bind = "[{'tipoVinculo': 'ALUNO'}, {'tipoVinculo': 'SERVIDOR'}]"
        user = self.make_user(bind=bind)
        self.assertTrue(user.is_servidor())

    def test_is_servidor_not(self):
        bind = "[{'tipoVinculo': 'ALUNO'}, {'tipoVinculo': 'ALUNO'}]"
        user = self.make_user(bind=bind)
        self.assertFalse(user.is_servidor())

    def test_unidade_is_allowed(self):
        bind = "[{'codigoUnidade': '12'}, {'codigoUnidade': '14', 'tipoVinculo': 'SERVIDOR'}]"
        user = self.make_user(bind=bind)
        self.assertTrue(user.unidade_is_allowed())

    def test_unidade_is_allowed_not(self):
        bind = "[{'codigoUnidade': '12'}, {'codigoUnidade': '13', 'tipoVinculo': 'SERVIDOR'}]"
        user = self.make_user(bind=bind)
        self.assertFalse(user.unidade_is_allowed())

    def make_user(self, **kwargs):
        default = dict(login='4444444', main_email='main@test.com', password='92874',
                       name='Marc Stold Further', user_type='I ')
        data = dict(default, **kwargs)
        return UserModel.objects.create_user(**data)



from django.contrib.auth.models import BaseUserManager
from django.utils.translation import gettext_lazy as _
from django.utils import timezone


class UserManager(BaseUserManager):
    def _create_user(self, login, name, user_type, main_email, password,
                     is_staff, is_superuser, **extra_fields):

        now = timezone.now()

        self._validate_fields(login=login, name=name, user_type=user_type)
        main_email = self.normalize_email(main_email)

        user = self.model(login=login, name=name, user_type=user_type,
                          main_email=main_email, is_staff=is_staff,
                          is_active=True, is_superuser=is_superuser,
                          last_login=now, date_joined=now, **extra_fields)

        if not password:
            password = extra_fields.get('wsuserid')

        user.set_password(password)
        user.save(using=self.db)
        return user

    def _update_or_create_user(self, login, name, user_type, main_email,
                               password, is_staff, is_superuser,
                               **extra_fields):

        now = timezone.now()
        self._validate_fields(login=login, name=name, user_type=user_type)

        main_email = self.normalize_email(main_email)
        user_data = dict(name=name, user_type=user_type, main_email=main_email,
                         is_staff=is_staff, is_active=True,
                         is_superuser=is_superuser, last_login=now,
                         date_joined=now, **extra_fields)

        user, create = self.model.objects.update_or_create(login=login,
                                                           defaults=user_data)
        if not password:
            password = extra_fields.get('wsuserid')

        user.set_password(password)
        user.save(using=self.db)

        return (user, create)

    def _validate_fields(self, login, name, user_type):
        if not login:
            raise ValueError(_('The login must be set.'))
        if not name:
            raise ValueError(_('The name must be set.'))
        if not user_type:
            raise ValueError(_('The type must be set'))

    def create_user(self, login, name, user_type, main_email=None,
                    password=None, **extra_fields):

        return self._create_user(login, name, user_type, main_email,
                                 password, False, False, **extra_fields)

    def update_or_create_user(self, login, name, user_type, main_email=None,
                              password=None, **extra_fields):
        return self._update_or_create_user(login, name, user_type, main_email,
                                           password, False, False,
                                           **extra_fields)

    def create_superuser(self, login, name, user_type, main_email,
                         password, **extra_fields):

        user = self._create_user(login, name, user_type, main_email, password,
                                 True, True, **extra_fields)
        user.is_active = True
        user.save(using=self._db)
        return user



from django.contrib import admin

from .models import UserModel


class UserModelAdmin(admin.ModelAdmin):
    list_display = ('name', 'login', 'user_type', 'main_email',
                    'alternative_email', 'usp_email', 'formatted_phone')


admin.site.register(UserModel, UserModelAdmin)
admin.site.site_header = 'Usuários'
admin.site.site_title = 'Usuários'
admin.site.index_title = 'Usuários'



from django.conf import settings
from authlib.integrations.django_client import OAuth


RESOURCE_URL = '/wsusuario/oauth/usuariousp'


class OAuthSettings:
    def __init__(self):
        self.base_url = 'https://uspdigital.usp.br/wsusuario/oauth'
        self.oauth = OAuth()

    def create(self):
        base_url = self.base_url
        callback_id = getattr(settings, 'OAUTH_CALLBACK_ID')
        self.oauth.register(
            name='usp',
            request_token_url=base_url + '/request_token',
            access_token_url=base_url + '/access_token',
            authorize_url=base_url +
            '/authorize?callback_id={}'.format(callback_id),
            api_base_url='https://uspdigital.usp.br/'
        )
        return self.oauth


class OAuthUsp:
    def __init__(self):
        oauth_usp = OAuthSettings().create()
        self.oauth_usp = oauth_usp.create_client('usp')
        self.redirect_uri = getattr(settings, 'REDIRECT_URI')

    def get_authorize_redirect(self, request):
        oauth_usp = self.oauth_usp
        authorize_redirect = oauth_usp.authorize_redirect(
            request, self.redirect_uri)
        return authorize_redirect

    def get_resource(self, request):
        oauth_usp = self.oauth_usp
        token = oauth_usp.authorize_access_token(request)
        resource = oauth_usp.post(RESOURCE_URL, token=token)
        return resource.json()



import json
from django.test import TestCase
from django.http import HttpRequest, QueryDict
from django.conf import settings
from django.contrib.sessions.backends.db import SessionStore

from ..oauth import OAuthUsp
from .mock import mock_oauth, token, resource, verifier


class OAuthUspTest(TestCase):
    def setUp(self):
        self.obj = OAuthUsp()

    def test_has_attribute_oauth_usp(self):
        self.assertTrue(hasattr(self.obj, 'oauth_usp'))

    @mock_oauth
    def test_get_authorize_redirect(self):
        request = HttpRequest
        setattr(request, 'session', {})
        resp = self.obj.get_authorize_redirect(request)
        expected = 'https://uspdigital.usp.br/wsusuario/oauth/authorize'
        self.assertIn(expected, resp.url)

    @mock_oauth
    def test_get_resource(self):
        request = HttpRequest()
        query = QueryDict(
            'oauth_token=12345oauth&oauth_verifier=12345veriifer')

        request.GET = query

        session = SessionStore()
        setattr(request, 'session', session)

        request_token = dict(
            oauth_token='token123', oauth_token_secret='oauth_token_secret123',
            oauth_verifier='verifier123')
        data = {"data": {"request_token": request_token}}
        request.session['_state_usp_12345oauth'] = data

        resp = self.obj.get_resource(request)
        expected = json.loads(resource)
        self.assertDictEqual(expected, resp)



from django.test import TestCase
from django.http import HttpRequest
from django.contrib.sessions.backends.db import SessionStore

from ..middleware import OAuthUspMiddleware
from .faker import data as user_data
from ..models import UserModel


def get_response(request):
    pass


class OAuthUspMiddlewareTest(TestCase):
    def setUp(self):
        self.obj = OAuthUspMiddleware(get_response)

    def test_has_call_attribute(self):
        self.assertTrue(hasattr(self.obj, '__call__'))

    def test_call_(self):
        user_data['bind'] = '[{"codigoUnidade": "10"}]'
        user = UserModel.objects.create_user(**user_data)
        self.client.force_login(user)

        request = HttpRequest()
        setattr(request, 'user', user)

        session = SessionStore()
        setattr(request, 'session', session)

        resp = self.obj.__call__(request)
        self.assertEqual(403, resp.status_code)



import httpretty
import functools


def mock_oauth(fn):
    @functools.wraps(fn)
    @httpretty.activate
    def wrapper(*args, **kwargs):
        register_oauth_uri()
        response = fn(*args, **kwargs)
        return response
    return wrapper


def register_oauth_uri():
    uri_list = mock_oauth_uri()
    for uri in uri_list:
        httpretty.register_uri(
            getattr(httpretty, uri.get('method')),
            uri=uri.get('uri'),
            body=uri.get('body'),
            headers=uri.get('headers')
        )


token = '123456'
secret = '123456789'
verifier = '778899'

resource = '{"loginUsuario":"login_test", "nomeUsuario":"Name test", "tipoUsuario":"I", "emailPrincipalUsuario":"test@test.com"}'


def mock_oauth_uri():
    base_url = 'https://uspdigital.usp.br/wsusuario/oauth'

    return [
        {
            'uri': base_url + '/request_token',
            'method': 'POST',
            'headers': {'Content-Type': 'application/x-www-form-urlencoded'},
            'body': 'oauth_token={}&oauth_token_secret={}'.format(token, secret),
        },
        {
            'uri': base_url + '/access_token',
            'method': 'POST',
            'headers': {'Content-Type': 'application/x-www-form-urlencoded'},
            'body': 'oauth_token={}&oauth_token_secret={}&verifier={}'.format(token,
                                                                              secret, verifier),
        },
        {
            'uri': base_url + '/authorize',
            'method': 'POST',
            'headers': {'Content-Type': 'application/x-www-form-urlencoded'},
            'body': 'oauth_token={}&oauth_token_secret={}&verifier={}'.format(token,
                                                                              secret, verifier),
        },
        {
            'uri': base_url + '/usuariousp',
            'method': 'POST',
            'headers': {'Content-Type': 'application/json'},
            'body': resource,
        }
    ]



class Mapper:
    def get_mapper(self):
        return {
            'loginUsuario': 'login',
            'nomeUsuario': 'name',
            'tipoUsuario': 'user_type',
            'emailPrincipalUsuario': 'main_email',
            'emailAlternativoUsuario': 'alternative_email',
            'emailUspUsuario': 'usp_email',
            'numeroTelefoneFormatado': 'formatted_phone',
            'wsuserid': 'wsuserid',
            'vinculo': 'bind'
        }


class Transform:
    mapper = Mapper

    def transform_data(self, data):
        mapper = self.mapper().get_mapper()
        transformed = dict()
        for key in mapper:
            if key in data:
                transformed.update({mapper.get(key): str(data.get(key))})

        return transformed



# Generated by Django 3.1 on 2020-08-19 02:42

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('login', models.CharField(max_length=50, unique=True, verbose_name='login')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('user_type', models.CharField(max_length=1, verbose_name='user type')),
                ('main_email', models.EmailField(max_length=50, verbose_name='main email')),
                ('alternative_email', models.EmailField(max_length=254, verbose_name='alternative email')),
                ('usp_email', models.EmailField(max_length=254, verbose_name='email usp')),
                ('formatted_phone', models.CharField(max_length=50, verbose_name='phone')),
                ('wsuserid', models.CharField(max_length=1024, verbose_name='wsuserid')),
                ('bind', models.TextField(verbose_name='bind')),
                ('is_staff', models.BooleanField(verbose_name='is staff')),
                ('is_active', models.BooleanField(verbose_name='is active')),
                ('date_joined', models.DateTimeField(auto_now_add=True, verbose_name='Joined at')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
        ),
    ]
